# Generated by Django 3.0 on 2019-12-18 12:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('olaii_stripe', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentmethod',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
    ]
