# Generated by Django 3.0.1 on 2019-12-27 10:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('olaii_stripe', '0002_paymentmethod_deleted'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentintent',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
